@@ -847,3 +847,10 @@ mod tests {
         assert_eq!(info.samples_per_pixel(), 4);
     }
 }
+
+#[cfg(feature = "bin")]
+#[no_mangle]
+pub unsafe extern "C"
+fn main(_argc: u32, _argv: *const *const i8) -> u32 {
+    0
+}
